# Maxlib for MG-GY 8411

This library re-package all the helper code from Max project into a libary.
This is only a simple porting. No refactoring is done.

## Changes

In order to be compatible with the latest `polygon-api-client`.
- `client = RESTClient(key)` instead of the context syntax `with RESTClient(key) as client`
- `client.get_real_time_currency_conversion` is the new method. See official documentation https://polygon-api-client.readthedocs.io/en/latest/Quotes.html#polygon.RESTClient.get_real_time_currency_conversion

## Key issue

Unfortunately the key is not working.

## Modules

- `collect.py` contains the entry points to collect and aggregate online and offline data.
    - `main()`
    - `main_offline()`
- `current.py` contains all the currency pair classes.
- `db.py` all the database utilities
- `portfolio.py`
- `utils.py` miscellaneous util functions


